"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const lisk_sdk_1 = require("lisk-sdk");
class ValidateCommand extends command_1.Command {
    async run() {
        const { args: { address }, } = this.parse(ValidateCommand);
        try {
            lisk_sdk_1.cryptography.validateBase32Address(address, this.config.pjson.lisk.addressPrefix);
            this.log(`Address ${address} is a valid address.`);
        }
        catch (error) {
            this.error(error.message);
        }
    }
}
exports.default = ValidateCommand;
ValidateCommand.description = 'Validate base32 address.';
ValidateCommand.examples = ['account:validate lskoaknq582o6fw7sp82bm2hnj7pzp47mpmbmux2g'];
ValidateCommand.args = [
    {
        name: 'address',
        required: true,
        description: 'Address in base32 format to validate.',
    },
];
//# sourceMappingURL=validate.js.map