"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_sdk_1 = require("lisk-sdk");
const command_1 = require("@oclif/command");
const flags_1 = require("../../utils/flags");
const reader_1 = require("../../utils/reader");
const outputPublicKeyOptionDescription = 'Includes the public key in the output. This option is provided for the convenience of node operators.';
const processInputs = (passphrase, password, outputPublicKey) => {
    const encryptedPassphraseObject = lisk_sdk_1.cryptography.encryptPassphraseWithPassword(passphrase, password);
    const encryptedPassphrase = lisk_sdk_1.cryptography.stringifyEncryptedPassphrase(encryptedPassphraseObject);
    return outputPublicKey
        ? {
            encryptedPassphrase,
            publicKey: lisk_sdk_1.cryptography.getKeys(passphrase).publicKey.toString('hex'),
        }
        : { encryptedPassphrase };
};
class EncryptCommand extends command_1.Command {
    async run() {
        const { flags: { passphrase: passphraseSource, password: passwordSource, 'output-public-key': outputPublicKey, }, } = this.parse(EncryptCommand);
        const passphrase = passphraseSource !== null && passphraseSource !== void 0 ? passphraseSource : (await reader_1.getPassphraseFromPrompt('passphrase', true));
        const password = passwordSource !== null && passwordSource !== void 0 ? passwordSource : (await reader_1.getPassphraseFromPrompt('password', true));
        const result = processInputs(passphrase, password, outputPublicKey);
        this.printJSON(result);
    }
    printJSON(message, pretty = false) {
        if (pretty) {
            this.log(JSON.stringify(message, undefined, '  '));
        }
        else {
            this.log(JSON.stringify(message));
        }
    }
}
exports.default = EncryptCommand;
EncryptCommand.description = 'Encrypt secret passphrase using password.';
EncryptCommand.examples = [
    'passphrase:encrypt',
    'passphrase:encrypt --passphrase your-passphrase',
    'passphrase:encrypt --password your-password',
    'passphrase:encrypt --output-public-key',
];
EncryptCommand.flags = {
    password: command_1.flags.string(flags_1.flags.password),
    passphrase: command_1.flags.string(flags_1.flags.passphrase),
    'output-public-key': command_1.flags.boolean({
        description: outputPublicKeyOptionDescription,
    }),
};
//# sourceMappingURL=encrypt.js.map